# Espera

**Espera** es una librería simple en Python que permite pausar la ejecución de un programa por un período de tiempo determinado y ejecutar una acción opcional al finalizar el tiempo de espera.

## Instalación

Puedes instalar **espera** usando `pip` directamente desde PyPI (una vez que lo hayas subido) o desde un archivo local. Para instalar desde PyPI:

```bash
pip install espera
